import { BaseApiClient } from "./baseApiClient";
import { CreateWorkingFolderResponse, GenerateApiResponse, StartBatchJobResponse } from "./responseTypes";
export declare class GenerateApiClient extends BaseApiClient {
    constructor(generateConnector: string);
    /**
     * Creates a working folder for your batch job.
     * @param name Name of the working folder.
     * @param expiration [Optional] Expiration date of the working folder.
     * @returns Response from the cloud containing a workingFolderId parameter of the created working folder.
     */
    createWorkingFolder(name: string, expiration?: Date): Promise<CreateWorkingFolderResponse>;
    /**
     * Increases the hit count for the specified processing pipeline. After a specific number of hits (set in GUI), the pipeline is triggered.
     * @param pipelineName Name of the processing pipeline.
     * @returns General response from the cloud.
     */
    increaseHitCount(pipelineName: string): Promise<GenerateApiResponse>;
    /**
     * Increases the hit count for the specified processing pipeline. After a specific number of hits (set in GUI), the pipeline is triggered.
     * This method is compatible with Quadient Cloud versions 23.08 and later.
     * @param pipelineName Name of the processing pipeline.
     * @param increaseAmount Amount of the hit count increase.
     * @returns General response from the cloud.
     */
    increaseHitCount(pipelineName: string, increaseAmount: number): Promise<GenerateApiResponse>;
    /**
     * Starts a batch job using a defined processing pipeline.
     * @param pipelineName Name of the processing pipeline.
     * @param workingFolderId [Optional] Identifier of a custom working folder. If specified, the processing pipeline will run using the custom working folder.
     * @returns Response from the cloud containing a batchJobId parameter of the created batch job.
     */
    startBatchJob(pipelineName: string, workingFolderId?: string): Promise<StartBatchJobResponse>;
}
