import { BaseApiClient } from "./baseApiClient";
import { Endpoints } from "./endpoints";
export class GenerateApiClient extends BaseApiClient {
    constructor(generateConnector) {
        super(generateConnector);
    }
    /**
     * Creates a working folder for your batch job.
     * @param name Name of the working folder.
     * @param expiration [Optional] Expiration date of the working folder.
     * @returns Response from the cloud containing a workingFolderId parameter of the created working folder.
     */
    async createWorkingFolder(name, expiration) {
        const endpoint = Endpoints.CreateWorkingFolder;
        const body = JSON.stringify({
            name: name,
            expiration: expiration === null || expiration === void 0 ? void 0 : expiration.toISOString(),
        });
        return await this.internalFetch(endpoint, body);
    }
    async increaseHitCount(pipelineName, increaseAmount) {
        const endpoint = Endpoints.IncreaseHitCount;
        const body = JSON.stringify({
            pipelineName: pipelineName,
            increaseAmount: increaseAmount,
        });
        return await this.internalFetch(endpoint, body);
    }
    /**
     * Starts a batch job using a defined processing pipeline.
     * @param pipelineName Name of the processing pipeline.
     * @param workingFolderId [Optional] Identifier of a custom working folder. If specified, the processing pipeline will run using the custom working folder.
     * @returns Response from the cloud containing a batchJobId parameter of the created batch job.
     */
    async startBatchJob(pipelineName, workingFolderId) {
        const endpoint = Endpoints.StartBatchJob;
        const body = JSON.stringify({
            pipelineName: pipelineName,
            workingFolderId: workingFolderId,
        });
        return await this.internalFetch(endpoint, body);
    }
}
